@@ -79,11 +79,18 @@ msggrep --location="$distribution" $translation > $pofile
 tdir=$(mktemp -d)
 mkdir $tdir/$distribution
 
+if [  a"$4" == "a" ]; then
+# #1 / #2 / # 3 Errors in some pages
+# Po4a sometimes has troubles parsing \c - pattern (4) handles credentials.7.po and mkpasswd.1.po.; pattern (5) and (6) handle mkosi.1.po (OpenSuSE tumbleweed), (7) handles gawk(1)/Debian and (8) handles afmtodit.1.po [ see Debian #1036826 ] ; (9) und (10) handles update-openssh-known-hosts.8 (2024-11-05)
+cat $master | sed "s/^.ft C$/^\".ft C$/" | sed "s/^.ft P$/^\".ft P$/" | sed "s/\\\\fb/\\fB/" | sed 's/\.BR \(.*\)\\c/.BR \1/' | sed 's/\.UE \\c/.UE /' | sed 's/^\\c$//'| sed 's/\.BI \(.*\)\\c/.BI \1/' | sed 's/\.RI \(.*\)\\c/.RI \1/' | sed 's/^Timo Weingärtner \\c$/Timo Weingärtner/' | sed 's/^.ME \\c./.ME/' > $tdir/$distribution/$manname
+else
 # Remove / Uncomment some macros po4a cannot handle
 # #1 / #2 Errors in some pages
 # #3 / #4 The last two can be removed, if mkpasswd (Debian BTS #1036908) and gawk (fixed upstream) are fixed (or Debian #1036826)
 # #5 Po4a sometimes has troubles parsing \c - This crude pattern gets around this, but adding additional spaces and sometimes moving arguments into main text, see Debian #1036826
-cat $master | sed "s/^.ft C$/^\".ft C$/" | sed "s/^.ft P$/^\".ft P$/" | sed "s/\\\\fb/\\fB/" | sed "s/^\.BI \(\\\\.*\)\"\\\\c$/.BI \1\"/" | sed "s/^\.BR \(\\\\.*\)\"\\\\c$/.BI \1\"/" | sed "s/\\\\c$//"  > $tdir/$distribution/$manname
+# #6 / #7 handles update-openssh-known-hosts.8 (2024-11-05)
+cat $master | sed "s/^.ft C$/^\".ft C$/" | sed "s/^.ft P$/^\".ft P$/" | sed "s/\\\\fb/\\fB/" | sed "s/^\.BI \(\\\\.*\)\"\\\\c$/.BI \1\"/" | sed "s/^\.BR \(\\\\.*\)\"\\\\c$/.BI \1\"/" | sed "s/\\\\c$//" | sed 's/^Timo Weingärtner \\c$/Timo Weingärtner/' | sed 's/^.ME \\c./.ME/'  > $tdir/$distribution/$manname
+fi
 
 # Actual translation
 if [ -f noaddendum ]; then
@@ -93,6 +100,7 @@ if [ -f noaddendum ]; then
 	--option generated \
 	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,FN,NE,NS,EX,EE,Id,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|" \
 	--option unknown_macros=untranslated \
+	--option inline="MR" \
 	-m "$tdir/$distribution/$manname" \
 	-M "utf-8" \
 	-p "$pofile" \
@@ -105,6 +113,7 @@ else
 	--option generated \
 	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,NE,NS,EX,EE,Id,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|" \
 	--option unknown_macros=untranslated \
+	--option inline="MR" \
 	-m "$tdir/$distribution/$manname" \
 	-M "utf-8" \
 	-p "$pofile" \
@@ -130,5 +139,17 @@ if [ -f "$localized" ]; then
 	rm "$encoding"
 fi
 
+if [ -f "$localized" ]; then
+    # Fix for issue #18
+    # Fix .NM macro
+    # Man page name without suffix
+    pname=$(echo $manname | cut -d. -f1)
+    sed -i -e "s/^.Nm$/.Nm $pname/" "$localized"
+    sed -i -e "s/^.Nm ,$/.Nm $pname ,/" "$localized"
+    # Fix for issue #20
+    sed -i -e ':a;N;$!ba;s/link\nhttp/link http/g' "$localized"
+    sed -i -e ':a;N;$!ba;s/tty:\nlink/tty: link/g' "$localized"
+fi
+
 rm -f "$addendum" "$pofile"
 rm -rf $tdir
